from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ControllerInfo(_message.Message):
    __slots__ = ("type", "p_gain", "i_gain", "d_gain")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    P_GAIN_FIELD_NUMBER: _ClassVar[int]
    I_GAIN_FIELD_NUMBER: _ClassVar[int]
    D_GAIN_FIELD_NUMBER: _ClassVar[int]
    type: int
    p_gain: float
    i_gain: float
    d_gain: float
    def __init__(self, type: _Optional[int] = ..., p_gain: _Optional[float] = ..., i_gain: _Optional[float] = ..., d_gain: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.rolling.map_msgs.msg import projected_map_info_pb2 as _projected_map_info_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ProjectedMapsInfoRequest(_message.Message):
    __slots__ = ("projected_maps_info",)
    PROJECTED_MAPS_INFO_FIELD_NUMBER: _ClassVar[int]
    projected_maps_info: _containers.RepeatedCompositeFieldContainer[_projected_map_info_pb2.ProjectedMapInfo]
    def __init__(self, projected_maps_info: _Optional[_Iterable[_Union[_projected_map_info_pb2.ProjectedMapInfo, _Mapping]]] = ...) -> None: ...

class ProjectedMapsInfoResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mavros_msgs/msg/gpsrtk.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/rolling/mavros_msgs/msg/gpsrtk.proto\x12,make87_messages_ros2.rolling.mavros_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\x9c\x02\n\x06GPSRTK\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x17\n\x0frtk_receiver_id\x18\x02 \x01(\r\x12\n\n\x02wn\x18\x03 \x01(\x05\x12\x0b\n\x03tow\x18\x04 \x01(\r\x12\x12\n\nrtk_health\x18\x05 \x01(\r\x12\x10\n\x08rtk_rate\x18\x06 \x01(\r\x12\r\n\x05nsats\x18\x07 \x01(\r\x12\x12\n\nbaseline_a\x18\x08 \x01(\x05\x12\x12\n\nbaseline_b\x18\t \x01(\x05\x12\x12\n\nbaseline_c\x18\n \x01(\x05\x12\x10\n\x08\x61\x63\x63uracy\x18\x0b \x01(\r\x12\x1a\n\x12iar_num_hypotheses\x18\x0c \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mavros_msgs.msg.gpsrtk_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GPSRTK']._serialized_start=164
  _globals['_GPSRTK']._serialized_end=448
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.lifecycle_msgs.msg import transition_pb2 as _transition_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ChangeStateRequest(_message.Message):
    __slots__ = ("transition",)
    TRANSITION_FIELD_NUMBER: _ClassVar[int]
    transition: _transition_pb2.Transition
    def __init__(self, transition: _Optional[_Union[_transition_pb2.Transition, _Mapping]] = ...) -> None: ...

class ChangeStateResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/moveit_msgs/msg/planning_scene_world.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.moveit_msgs.msg import collision_object_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_collision__object__pb2
from make87_messages_ros2.rolling.octomap_msgs.msg import octomap_with_pose_pb2 as make87__messages__ros2_dot_rolling_dot_octomap__msgs_dot_msg_dot_octomap__with__pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/rolling/moveit_msgs/msg/planning_scene_world.proto\x12,make87_messages_ros2.rolling.moveit_msgs.msg\x1a\x43make87_messages_ros2/rolling/moveit_msgs/msg/collision_object.proto\x1a\x45make87_messages_ros2/rolling/octomap_msgs/msg/octomap_with_pose.proto\"\xbf\x01\n\x12PlanningSceneWorld\x12X\n\x11\x63ollision_objects\x18\x01 \x03(\x0b\x32=.make87_messages_ros2.rolling.moveit_msgs.msg.CollisionObject\x12O\n\x07octomap\x18\x02 \x01(\x0b\x32>.make87_messages_ros2.rolling.octomap_msgs.msg.OctomapWithPoseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.moveit_msgs.msg.planning_scene_world_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PLANNINGSCENEWORLD']._serialized_start=262
  _globals['_PLANNINGSCENEWORLD']._serialized_end=453
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rc_reason_msgs/srv/detect_tags.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.rolling.rc_common_msgs.msg import return_code_pb2 as make87__messages__ros2_dot_rolling_dot_rc__common__msgs_dot_msg_dot_return__code__pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import detected_tag_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_detected__tag__pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import tag_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_tag__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/rolling/rc_reason_msgs/srv/detect_tags.proto\x12/make87_messages_ros2.rolling.rc_reason_msgs.srv\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\x1a\x41make87_messages_ros2/rolling/rc_common_msgs/msg/return_code.proto\x1a\x42make87_messages_ros2/rolling/rc_reason_msgs/msg/detected_tag.proto\x1a\x39make87_messages_ros2/rolling/rc_reason_msgs/msg/tag.proto\"\xb5\x01\n\x11\x44\x65tectTagsRequest\x12\x42\n\x04tags\x18\x01 \x03(\x0b\x32\x34.make87_messages_ros2.rolling.rc_reason_msgs.msg.Tag\x12\x12\n\npose_frame\x18\x02 \x01(\t\x12H\n\nrobot_pose\x18\x03 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\"\x80\x02\n\x12\x44\x65tectTagsResponse\x12J\n\x04tags\x18\x01 \x03(\x0b\x32<.make87_messages_ros2.rolling.rc_reason_msgs.msg.DetectedTag\x12L\n\ttimestamp\x18\x02 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12P\n\x0breturn_code\x18\x03 \x01(\x0b\x32;.make87_messages_ros2.rolling.rc_common_msgs.msg.ReturnCodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rc_reason_msgs.srv.detect_tags_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DETECTTAGSREQUEST']._serialized_start=436
  _globals['_DETECTTAGSREQUEST']._serialized_end=617
  _globals['_DETECTTAGSRESPONSE']._serialized_start=620
  _globals['_DETECTTAGSRESPONSE']._serialized_end=876
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Status(_message.Message):
    __slots__ = ("header", "caret_node_name", "status", "node_names", "pid")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CARET_NODE_NAME_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    NODE_NAMES_FIELD_NUMBER: _ClassVar[int]
    PID_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    caret_node_name: str
    status: int
    node_names: _containers.RepeatedScalarFieldContainer[str]
    pid: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., caret_node_name: _Optional[str] = ..., status: _Optional[int] = ..., node_names: _Optional[_Iterable[str]] = ..., pid: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class RadarReturn(_message.Message):
    __slots__ = ("range", "azimuth", "elevation", "doppler_velocity", "amplitude")
    RANGE_FIELD_NUMBER: _ClassVar[int]
    AZIMUTH_FIELD_NUMBER: _ClassVar[int]
    ELEVATION_FIELD_NUMBER: _ClassVar[int]
    DOPPLER_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    AMPLITUDE_FIELD_NUMBER: _ClassVar[int]
    range: float
    azimuth: float
    elevation: float
    doppler_velocity: float
    amplitude: float
    def __init__(self, range: _Optional[float] = ..., azimuth: _Optional[float] = ..., elevation: _Optional[float] = ..., doppler_velocity: _Optional[float] = ..., amplitude: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rcl_interfaces/srv/get_parameters.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rcl_interfaces.msg import parameter_value_pb2 as make87__messages__ros2_dot_rolling_dot_rcl__interfaces_dot_msg_dot_parameter__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/rolling/rcl_interfaces/srv/get_parameters.proto\x12/make87_messages_ros2.rolling.rcl_interfaces.srv\x1a\x45make87_messages_ros2/rolling/rcl_interfaces/msg/parameter_value.proto\"%\n\x14GetParametersRequest\x12\r\n\x05names\x18\x01 \x03(\t\"h\n\x15GetParametersResponse\x12O\n\x06values\x18\x01 \x03(\x0b\x32?.make87_messages_ros2.rolling.rcl_interfaces.msg.ParameterValueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rcl_interfaces.srv.get_parameters_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETPARAMETERSREQUEST']._serialized_start=192
  _globals['_GETPARAMETERSREQUEST']._serialized_end=229
  _globals['_GETPARAMETERSRESPONSE']._serialized_start=231
  _globals['_GETPARAMETERSRESPONSE']._serialized_end=335
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.py_trees_ros_interfaces.msg import subscriber_details_pb2 as _subscriber_details_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IntrospectSubscribersRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class IntrospectSubscribersResponse(_message.Message):
    __slots__ = ("subscriber_details",)
    SUBSCRIBER_DETAILS_FIELD_NUMBER: _ClassVar[int]
    subscriber_details: _containers.RepeatedCompositeFieldContainer[_subscriber_details_pb2.SubscriberDetails]
    def __init__(self, subscriber_details: _Optional[_Iterable[_Union[_subscriber_details_pb2.SubscriberDetails, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from make87_messages_ros2.rolling.tuw_nav_msgs.msg import float64_array_pb2 as _float64_array_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Spline(_message.Message):
    __slots__ = ("header", "knots", "ctrls")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    KNOTS_FIELD_NUMBER: _ClassVar[int]
    CTRLS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    knots: _containers.RepeatedScalarFieldContainer[float]
    ctrls: _containers.RepeatedCompositeFieldContainer[_float64_array_pb2.Float64Array]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., knots: _Optional[_Iterable[float]] = ..., ctrls: _Optional[_Iterable[_Union[_float64_array_pb2.Float64Array, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rc_reason_msgs/srv/hand_eye_calibration_trigger.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRmake87_messages_ros2/rolling/rc_reason_msgs/srv/hand_eye_calibration_trigger.proto\x12/make87_messages_ros2.rolling.rc_reason_msgs.srv\"\"\n HandEyeCalibrationTriggerRequest\"U\n!HandEyeCalibrationTriggerResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rc_reason_msgs.srv.hand_eye_calibration_trigger_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_HANDEYECALIBRATIONTRIGGERREQUEST']._serialized_start=135
  _globals['_HANDEYECALIBRATIONTRIGGERREQUEST']._serialized_end=169
  _globals['_HANDEYECALIBRATIONTRIGGERRESPONSE']._serialized_start=171
  _globals['_HANDEYECALIBRATIONTRIGGERRESPONSE']._serialized_end=256
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.autoware_planning_msgs.msg import lanelet_primitive_pb2 as _lanelet_primitive_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LaneletSegment(_message.Message):
    __slots__ = ("header", "preferred_primitive", "primitives")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    PREFERRED_PRIMITIVE_FIELD_NUMBER: _ClassVar[int]
    PRIMITIVES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    preferred_primitive: _lanelet_primitive_pb2.LaneletPrimitive
    primitives: _containers.RepeatedCompositeFieldContainer[_lanelet_primitive_pb2.LaneletPrimitive]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., preferred_primitive: _Optional[_Union[_lanelet_primitive_pb2.LaneletPrimitive, _Mapping]] = ..., primitives: _Optional[_Iterable[_Union[_lanelet_primitive_pb2.LaneletPrimitive, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import color_rgba_pb2 as _color_rgba_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RightEyeLeds(_message.Message):
    __slots__ = ("colors",)
    COLORS_FIELD_NUMBER: _ClassVar[int]
    colors: _containers.RepeatedCompositeFieldContainer[_color_rgba_pb2.ColorRGBA]
    def __init__(self, colors: _Optional[_Iterable[_Union[_color_rgba_pb2.ColorRGBA, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/autoware_v2x_msgs/msg/virtual_gate_area_status.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOmake87_messages_ros2/jazzy/autoware_v2x_msgs/msg/virtual_gate_area_status.proto\x12\x30make87_messages_ros2.jazzy.autoware_v2x_msgs.msg\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\"\xff\x01\n\x15VirtualGateAreaStatus\x12\x46\n\x05stamp\x18\x01 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12\x0e\n\x06status\x18\x02 \x01(\r\x12\x13\n\x0bsequence_id\x18\x03 \x01(\r\x12\x0f\n\x07\x61rea_id\x18\x04 \x01(\t\x12\x10\n\x08gate_ids\x18\x05 \x03(\t\x12V\n\x15\x65xpected_time_arrival\x18\x06 \x03(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Timeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.autoware_v2x_msgs.msg.virtual_gate_area_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_VIRTUALGATEAREASTATUS']._serialized_start=196
  _globals['_VIRTUALGATEAREASTATUS']._serialized_end=451
# @@protoc_insertion_point(module_scope)
